@@ -173,12 +173,16 @@
 
 import logging
 from warnings import warn
-from typing import List
+from typing import List, Dict
 
-from ._config import BaseConfig, Config
+from ._config import Config
 from ._entity import BaseEntity, Entity, _ORMType
 from ._routing import BaseRouting, Routing
 from ._authentication import BaseAuthentication, Authentication
+from .oauth2.google import Google
+from .oauth2._base import BaseOAuth
+from .oauth2.http_requests import HttpRequests
+from .oauth2._urls import GOOGLE_OAUTH_URL
 
 # pylint:disable=invalid-name
 logger = logging.getLogger()
@@ -208,7 +212,7 @@ class JwtRoutes:
 
     #: The class that is used to create Config objects.  See :class:`~flask_jwt_router._config`
     #: for more information.
-    config: BaseConfig
+    config: Config
 
     #: The class that provides algorithms to :class:`~flask_jwt_router._jwt_routes`.
     # See :class:`~flask_jwt_router._authentication` for more information.
@@ -222,14 +226,19 @@ class JwtRoutes:
     #: for more information.
     routing: BaseRouting
 
-    #: The class that is used to create Config objects.  See :class:`~flask_jwt_router._config`
+    #: Optional Google OAuth 2.0 Single Sign On. See :class:`~flask_jwt_router.oauth2.google``
     #: for more information.
-    ext: BaseConfig
+    google: BaseOAuth
+
+    #: Optional. See :class:`~flask_jwt_router.oauth2.google`
+    google_oauth: Dict
 
     def __init__(self, app=None, **kwargs):
         self.entity_models = kwargs.get("entity_models")
+        self.google_oauth = kwargs.get("google_oauth")
         self.config = Config()
         self.auth = Authentication()
+        self.google = Google(HttpRequests(GOOGLE_OAUTH_URL))
         self.app = app
         if app:
             self.init_app(app, entity_models=self.entity_models)
@@ -242,10 +251,13 @@ class JwtRoutes:
         """
         self.app = app if app else self.app
         entity_models = self.entity_models or kwargs.get("entity_models")
+        self.google_oauth = self.google_oauth or kwargs.get("google_oauth")
         app_config = self.get_app_config(self.app)
-        self.config.init_config(app_config, entity_models=entity_models)
+        if self.google_oauth:
+            self.google.init(**self.google_oauth)
+        self.config.init_config(app_config, entity_models=entity_models, google_oauth=self.google_oauth)
         self.entity = Entity(self.config)
-        self.routing = Routing(self.app, self.config, self.entity)
+        self.routing = Routing(self.app, self.config, self.entity, self.google)
         self.app.before_request(self.routing.before_middleware)
         if self.config.expire_days:
             self.exp = self.config.expire_days
